/* eslint-env node */
/* global module: false, require: false */
'use strict';

const RSVP = require('rsvp');
const packages = [
  {name: 'babel-plugin-transform-object-rest-spread'},
  {name: 'normalize.css'},
  {name: 'matthewhudson/device.js'},
  {name: 'lodash.defaultsdeep'},
  {name: 'postcss-import'},
  {name: 'postcss-nesting', target: '^2.3.0'}, // v3 depends on postcss v6
  {name: 'postcss-extend'},
  {name: 'postcss-css-variables'},
  {name: 'postcss-custom-media'},
  {name: 'postcss-media-minmax'},
  {name: 'postcss-calc'},
  {name: 'postcss-short'},
  {name: 'postcss-clearfix'},
  {name: 'postcss-fallback'},
  {name: 'postcss-color-function'},
  {name: 'autoprefixer'},
  {name: 'postcss-merge-rules'},
  {name: 'postcss-discard-empty'},
  {name: 'postcss-discard-comments'},
  {name: 'postcss-discard-duplicates'},
];

module.exports = {
  name: 'ui-foundation',
  description: 'Blueprint for @choiceform/ui-foundation',

  normalizeEntityName(entityName) {
    return entityName;
  },

  afterInstall: function(options) {
    let isAddon = options.project.isEmberCLIAddon();

    this.ui.writeInfoLine(`正在为 ${isAddon ? 'addon' : 'application'} 安装依赖...`);
    this.ui.writeInfoLine(`Installing dependencies for ${isAddon ? 'addon' : 'application'} ...`);

    return this.addAddonToProject({name: 'ember-css-modules', target: '^0.7.0', blueprintOptions: {save: isAddon}})
      .then(() => this.addAddonToProject({name: 'ember-cli-node-assets'}))
      .then(() => this.addAddonToProject({name: 'ember-native-dom-helpers'}))
      .then(() => this.addAddonToProject({name: 'ember-native-dom-event-dispatcher', target: 'rwjblue/ember-native-dom-event-dispatcher'}))
      .then(() => this.addPackagesToProject(packages))
      .then(() => {
        this.ui.writeLine(`用于 ${isAddon ? 'Addon' : 'Application'}，请运行：`);
        this.ui.writeLine(`For ${isAddon ? 'Addon' : 'Application'} usage, please run:`);
        this.ui.writeInfoLine(`ember generate foundation-for-${isAddon ? 'addon' : 'app'}`);
        return RSVP.resolve();
      });
  },
}
