/* eslint-env node */
/* global module: false, require: false */
'use strict';

const fs = require('fs');
const path = require('path');
const defaultsDeep = require('lodash.defaultsdeep');

module.exports = {
  name: 'ui-foundation',

  isDevelopingAddon() {
    return true;
  },

  included(parent) {
    this.options = defaultsDeep(parent.options, this.options);

    this._super.included.apply(this, arguments);

    if (this.options.useNormalizeCSS) {
      this.import('vendor/normalize.css/normalize.css', {prepend: true});
    }

    if (this.options.useDeviceJS) {
      this.import('vendor/device.js/device.js', {outputFile: 'assets/device.js'});
      this.import('vendor/shims/device.js');
    }
  },

  contentFor(type, config, content) {
    switch (type) {
      case 'head': return this._contentForHead.call(this, config, content);
      case 'head-footer': return this._contentForHeadFooter.call(this, config, content);
      case 'body-footer': return this._contentForBodyFooter.call(this, config, content);
      default: return '';
    }
  },

  _contentForHead(config/*, content */) {
    let content = [];

    if (this.options.useDeviceJS) {
      content.push(`<script async src="${config.rootURL}assets/device.js"></script>`);
    }

    return content.join('\n');
  },

  _contentForHeadFooter(/* config, content */) {
    let content = [];

    if (this.options.disableInspectorInProductionMode && this.app.env === 'production') {
      content.push(`<script>window.NO_EMBER_DEBUG = true;</script>`);
    }

    return content.join('\n');
  },

  _contentForBodyFooter(/* config, content */) {
    let content = [];

    if (this.options.importSVGIcon) {
      // TODO find icons in app and append it to DOM as well
      let basePath = this._basePathForProject(this.project);
      let filePath = path.resolve(basePath, 'addon/svg-icon.html');
      content.push(fs.readFileSync(filePath, 'utf-8').replace(/\n\r?/g, ''));
    }

    return content.join('\n');
  },

  _basePathForProject({pkg, root, nodeModulesPath}) {
    return pkg.name.includes(this.name) ? root : path.join(nodeModulesPath, '@choiceform', this.name);
  },
};
